# emdapiclimate.ClimateDataApi

All URIs are relative to *http://api.emd.dk*

Method | HTTP request | Description
------------- | ------------- | -------------
[**climatedata_controller_get_climatecoverage**](ClimateDataApi.md#climatedata_controller_get_climatecoverage) | **GET** /coverage/{service_id} | Return list of nearest points (or nodes) for a given location
[**climatedata_controller_get_climatedataservices**](ClimateDataApi.md#climatedata_controller_get_climatedataservices) | **GET** /datasets | Return list of available climate dataset services
[**climatedata_controller_get_climateorder**](ClimateDataApi.md#climatedata_controller_get_climateorder) | **GET** /order/{service_id} | Place an order for a climate dataset (in order to climatedata_download a time-series). An unique order identifier is returned.
[**climatedata_controller_get_climatestatus**](ClimateDataApi.md#climatedata_controller_get_climatestatus) | **GET** /status/{order_id} | Return json with status (PENDING, STARTED, SUCCESS, FAILURE, RETRY, REVOKED, IGNORED) and download_url (when ready) for data order . Use download_url to climatedata_download.


# **climatedata_controller_get_climatecoverage**
> list[ClimateCoverageResult] climatedata_controller_get_climatecoverage(service_id, lat, lon, num_points=num_points, max_distance=max_distance)

Return list of nearest points (or nodes) for a given location

### Example

* Api Key Authentication (api_key):
```python
from __future__ import print_function
import time
import emdapiclimate
from emdapiclimate.rest import ApiException
from pprint import pprint
# Defining the host is optional and defaults to http://api.emd.dk
# See configuration.py for a list of all supported configuration parameters.
configuration = emdapiclimate.Configuration(
    host = "http://api.emd.dk"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: api_key
configuration = emdapiclimate.Configuration(
    host = "http://api.emd.dk",
    api_key = {
        'X-Auth': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-Auth'] = 'Bearer'

# Enter a context with an instance of the API client
with emdapiclimate.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = emdapiclimate.ClimateDataApi(api_client)
    service_id = 'service_id_example' # str | Service_id for the dataset
lat = 3.4 # float | Latitude for point (in decimal degrees)
lon = 3.4 # float | Longitude for point (in decimal degrees)
num_points = 1 # int | Number of points to return (optional) (default to 1)
max_distance = 150 # int | Maximum distance (radius) to find data (in km). (optional) (default to 150)

    try:
        # Return list of nearest points (or nodes) for a given location
        api_response = api_instance.climatedata_controller_get_climatecoverage(service_id, lat, lon, num_points=num_points, max_distance=max_distance)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ClimateDataApi->climatedata_controller_get_climatecoverage: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **service_id** | **str**| Service_id for the dataset | 
 **lat** | **float**| Latitude for point (in decimal degrees) | 
 **lon** | **float**| Longitude for point (in decimal degrees) | 
 **num_points** | **int**| Number of points to return | [optional] [default to 1]
 **max_distance** | **int**| Maximum distance (radius) to find data (in km). | [optional] [default to 150]

### Return type

[**list[ClimateCoverageResult]**](ClimateCoverageResult.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Successful operation. Nearby points found and data returned in list. |  -  |
**401** | License or token is expired. |  -  |
**403** | Forbidden - you do not have access to the requested resource. |  -  |
**404** | No data found within specified radius. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **climatedata_controller_get_climatedataservices**
> list[OnlineService] climatedata_controller_get_climatedataservices()

Return list of available climate dataset services

### Example

* Api Key Authentication (api_key):
```python
from __future__ import print_function
import time
import emdapiclimate
from emdapiclimate.rest import ApiException
from pprint import pprint
# Defining the host is optional and defaults to http://api.emd.dk
# See configuration.py for a list of all supported configuration parameters.
configuration = emdapiclimate.Configuration(
    host = "http://api.emd.dk"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: api_key
configuration = emdapiclimate.Configuration(
    host = "http://api.emd.dk",
    api_key = {
        'X-Auth': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-Auth'] = 'Bearer'

# Enter a context with an instance of the API client
with emdapiclimate.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = emdapiclimate.ClimateDataApi(api_client)
    
    try:
        # Return list of available climate dataset services
        api_response = api_instance.climatedata_controller_get_climatedataservices()
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ClimateDataApi->climatedata_controller_get_climatedataservices: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**list[OnlineService]**](OnlineService.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Successful operation - list of climate dataset returned |  -  |
**400** | No data found |  -  |
**401** | License or token is expired. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **climatedata_controller_get_climateorder**
> str climatedata_controller_get_climateorder(service_id, lat, lon, start_year, end_year, filetype)

Place an order for a climate dataset (in order to climatedata_download a time-series). An unique order identifier is returned.

### Example

* Api Key Authentication (api_key):
```python
from __future__ import print_function
import time
import emdapiclimate
from emdapiclimate.rest import ApiException
from pprint import pprint
# Defining the host is optional and defaults to http://api.emd.dk
# See configuration.py for a list of all supported configuration parameters.
configuration = emdapiclimate.Configuration(
    host = "http://api.emd.dk"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: api_key
configuration = emdapiclimate.Configuration(
    host = "http://api.emd.dk",
    api_key = {
        'X-Auth': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-Auth'] = 'Bearer'

# Enter a context with an instance of the API client
with emdapiclimate.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = emdapiclimate.ClimateDataApi(api_client)
    service_id = 'service_id_example' # str | Service_id of dataset considered
lat = 3.4 # float | Latitude for point (decimal degrees)
lon = 3.4 # float | Longitude for point
start_year = 56 # int | Start year
end_year = 56 # int | End year
filetype = 'filetype_example' # str | The file type to return from the call; zipraw is for native windpro use with import-filter included (if it exists), zipcsv and csv are ready-to-use csv-dataframes. Csv is tab-separated.

    try:
        # Place an order for a climate dataset (in order to climatedata_download a time-series). An unique order identifier is returned.
        api_response = api_instance.climatedata_controller_get_climateorder(service_id, lat, lon, start_year, end_year, filetype)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ClimateDataApi->climatedata_controller_get_climateorder: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **service_id** | **str**| Service_id of dataset considered | 
 **lat** | **float**| Latitude for point (decimal degrees) | 
 **lon** | **float**| Longitude for point | 
 **start_year** | **int**| Start year | 
 **end_year** | **int**| End year | 
 **filetype** | **str**| The file type to return from the call; zipraw is for native windpro use with import-filter included (if it exists), zipcsv and csv are ready-to-use csv-dataframes. Csv is tab-separated. | 

### Return type

**str**

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Successful operation - order identifier is returned - with order placed in the processing queue. |  -  |
**401** | License or token is expired. |  -  |
**403** | Forbidden - you do not have access to the requested resource. |  -  |
**404** | No data found or dataset-id not found |  -  |
**405** | Invalid filetype requested. |  -  |
**406** | Number of allowed active, parallel requests exceeded. |  -  |
**407** | Number of allowed requests in fair-use policy exceeded. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **climatedata_controller_get_climatestatus**
> InlineResponse200 climatedata_controller_get_climatestatus(order_id)

Return json with status (PENDING, STARTED, SUCCESS, FAILURE, RETRY, REVOKED, IGNORED) and download_url (when ready) for data order . Use download_url to climatedata_download.

### Example

* Api Key Authentication (api_key):
```python
from __future__ import print_function
import time
import emdapiclimate
from emdapiclimate.rest import ApiException
from pprint import pprint
# Defining the host is optional and defaults to http://api.emd.dk
# See configuration.py for a list of all supported configuration parameters.
configuration = emdapiclimate.Configuration(
    host = "http://api.emd.dk"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: api_key
configuration = emdapiclimate.Configuration(
    host = "http://api.emd.dk",
    api_key = {
        'X-Auth': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-Auth'] = 'Bearer'

# Enter a context with an instance of the API client
with emdapiclimate.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = emdapiclimate.ClimateDataApi(api_client)
    order_id = 'order_id_example' # str | Order_id of request to check for status

    try:
        # Return json with status (PENDING, STARTED, SUCCESS, FAILURE, RETRY, REVOKED, IGNORED) and download_url (when ready) for data order . Use download_url to climatedata_download.
        api_response = api_instance.climatedata_controller_get_climatestatus(order_id)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ClimateDataApi->climatedata_controller_get_climatestatus: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **order_id** | **str**| Order_id of request to check for status | 

### Return type

[**InlineResponse200**](InlineResponse200.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Successful operation - status is returned |  -  |
**401** | License or token is expired. |  -  |
**404** | No data found for requested id - or data-extraction failed. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

